@@ -20,6 +20,7 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+	"net/url"
 	"os"
 	"path/filepath"
 	"strings"
@@ -209,12 +210,16 @@ func (t TerraformDirectoryLoader) loadDirRecursive(dirList []string) (output.All
 				// resolve references
 				resourceConfig.Config = r.ResolveRefs(resourceConfig.Config.(jsonObj))
 
+				var isRemoteModule bool
 				// source file path
-				resourceConfig.Source, err = GetConfigSource(remoteURLMapping, resourceConfig, t.absRootDir)
+				resourceConfig.Source, isRemoteModule, err = GetConfigSource(remoteURLMapping, resourceConfig, t.absRootDir)
 				if err != nil {
 					t.addError(err.Error(), dir)
 					continue
 				}
+				if isRemoteModule {
+					resourceConfig.IsRemoteModule = &isRemoteModule
+				}
 
 				// tf plan directory relative path
 				planRoot, err := filepath.Rel(t.absRootDir, dir)
@@ -332,14 +337,18 @@ func (t TerraformDirectoryLoader) loadDirNonRecursive() (output.AllResourceConfi
 
 			// resolve references
 			resourceConfig.Config = r.ResolveRefs(resourceConfig.Config.(jsonObj))
-
+			var isRemoteModule bool
 			// source file path
-			resourceConfig.Source, err = GetConfigSource(remoteURLMapping, resourceConfig, t.absRootDir)
+			resourceConfig.Source, isRemoteModule, err = GetConfigSource(remoteURLMapping, resourceConfig, t.absRootDir)
 			if err != nil {
 				errMessage := fmt.Sprintf("failed to get resource's filepath: %v", err)
 				return allResourcesConfig, multierror.Append(t.errIacLoadDirs, results.DirScanErr{IacType: "terraform", Directory: t.absRootDir, ErrMessage: errMessage})
 			}
 
+			if isRemoteModule {
+				resourceConfig.IsRemoteModule = &isRemoteModule
+			}
+
 			// add tf plan directory relative path
 			resourceConfig.PlanRoot = fmt.Sprintf(".%s", string(os.PathSeparator))
 
@@ -489,29 +498,38 @@ func GetRemoteLocation(cache map[string]string, resourcePath string) (remoteURL,
 }
 
 // GetConfigSource - get the source path for the resource
-func GetConfigSource(remoteURLMapping map[string]string, resourceConfig output.ResourceConfig, absRootDir string) (string, error) {
+func GetConfigSource(remoteURLMapping map[string]string, resourceConfig output.ResourceConfig, absRootDir string) (string, bool, error) {
 	var (
-		source string
-		err    error
-		rel    string
+		source   string
+		err      error
+		rel      string
+		isRemote bool
 	)
+
 	// Get source path if remote module used
 	remoteURL, tempDir := GetRemoteLocation(remoteURLMapping, resourceConfig.Source)
 	if remoteURL != "" {
 		rel, err = filepath.Rel(tempDir, resourceConfig.Source)
 		if err != nil {
 			errMessage := fmt.Sprintf("failed to get remote resource's %s filepath: %v", resourceConfig.Name, err)
-			return source, errors.New(errMessage)
+			return source, false, errors.New(errMessage)
+		}
+		isRemote = true
+
+		source = filepath.Join(url.PathEscape(remoteURL), rel)
+		source, err = url.PathUnescape(source)
+		if err != nil {
+			errMessage := fmt.Sprintf("failed to get remote resource's %s filepath: %v", resourceConfig.Name, err)
+			return source, false, errors.New(errMessage)
 		}
-		source = filepath.Join(filepath.Clean(remoteURL), rel)
 	} else {
 		// source file path
 		source, err = filepath.Rel(absRootDir, resourceConfig.Source)
 		if err != nil {
-			return source, err
+			return source, false, err
 		}
 	}
-	return source, nil
+	return source, isRemote, nil
 }
 
 // GetRemoteModuleIfPresentInTerraformSrc - Gets the remote module if present in terraform init cache
