@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2020 Accurics, Inc.
+    Copyright (C) 2022 Tenable, Inc.
 
 	Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -17,8 +17,8 @@
 package tfv15
 
 import (
-	"github.com/accurics/terrascan/pkg/iac-providers/output"
-	commons "github.com/accurics/terrascan/pkg/iac-providers/terraform/commons"
+	"github.com/tenable/terrascan/pkg/iac-providers/output"
+	commons "github.com/tenable/terrascan/pkg/iac-providers/terraform/commons"
 )
 
 // LoadIacFile parses the given terraform file from the given file path
