@@ -19,13 +19,14 @@ package config
 import (
 	"encoding/json"
 
-	"github.com/awslabs/goformation/v6/cloudformation/s3"
+	"github.com/awslabs/goformation/v7/cloudformation/s3"
 )
 
 // S3BucketPolicyConfig holds config for aws_s3_bucket_policy
 type S3BucketPolicyConfig struct {
 	Config
 	PolicyDocument string `json:"policy"`
+	Bucket         string `json:"bucket"`
 }
 
 // GetS3BucketPolicyConfig returns config for aws_s3_bucket_policy
@@ -34,6 +35,7 @@ func GetS3BucketPolicyConfig(p *s3.BucketPolicy) []AWSResourceConfig {
 		Config: Config{
 			Name: p.Bucket,
 		},
+		Bucket: p.Bucket,
 	}
 
 	policyDocument, err := json.Marshal(p.PolicyDocument)
